# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/kscc/announcement/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/kscc/announcement/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Kscc\\Announcement\\": "packages/kscc/announcement/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Kscc\Announcement\Providers\AnnouncementServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Announcement'  => Kscc\Announcement\Facades\Announcement::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Kscc\\AnnouncementTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Kscc\Announcement\Providers\AnnouncementServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Kscc\Announcement\Providers\AnnouncementServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Kscc\Announcement\Providers\AnnouncementServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/announcement/{modulename}

**User**

    http://path-to-route-folder/user/announcement/{modulename}

**Public**

    http://path-to-route-folder/announcements


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/announcement/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/announcement/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/announcement/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/announcement/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/announcement/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/announcement/{modulename}/{slug}
    METHOD: GET