<?php

namespace Kscc\Announcement\Policies;

use Litepie\User\Contracts\UserPolicy;
use Kscc\Announcement\Models\Announcement;

class AnnouncementPolicy
{

    /**
     * Determine if the given user can view the announcement.
     *
     * @param UserPolicy $user
     * @param Announcement $announcement
     *
     * @return bool
     */
    public function view(UserPolicy $user, Announcement $announcement)
    {
        if ($user->canDo('announcement.announcement.view') && $user->isAdmin()) {
            return true;
        }

        return $announcement->user_id == user_id() && $announcement->user_type == user_type();
    }

    /**
     * Determine if the given user can create a announcement.
     *
     * @param UserPolicy $user
     * @param Announcement $announcement
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('announcement.announcement.create');
    }

    /**
     * Determine if the given user can update the given announcement.
     *
     * @param UserPolicy $user
     * @param Announcement $announcement
     *
     * @return bool
     */
    public function update(UserPolicy $user, Announcement $announcement)
    {
        if ($user->canDo('announcement.announcement.edit') && $user->isAdmin()) {
            return true;
        }

        return $announcement->user_id == user_id() && $announcement->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given announcement.
     *
     * @param UserPolicy $user
     * @param Announcement $announcement
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Announcement $announcement)
    {
        return $announcement->user_id == user_id() && $announcement->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given announcement.
     *
     * @param UserPolicy $user
     * @param Announcement $announcement
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Announcement $announcement)
    {
        if ($user->canDo('announcement.announcement.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given announcement.
     *
     * @param UserPolicy $user
     * @param Announcement $announcement
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Announcement $announcement)
    {
        if ($user->canDo('announcement.announcement.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
